@@ -1,6 +1,8 @@
 """ mmtools - status """
 
 import argparse
+import requests
+import sys
 
 from . import arguments
 from .mattermost import Mattermost
@@ -27,10 +29,15 @@ def main() -> None:
 
     args = parseargs()
 
-    mm = Mattermost(args)
-    mm.init_channels()
+    try:
+        mm = Mattermost(args)
+        mm.init_channels()
 
-    mm.i3blocks(args.ignore, args.channel_color, args.user_color, args.chat_prefix)
+        mm.i3blocks(args.ignore, args.channel_color, args.user_color, args.chat_prefix)
+    except requests.exceptions.ConnectionError:
+        msg = f"{args.chat_prefix.strip()} Connection error"
+        print(f"{msg}\n{msg}\n#FF0000")
+        sys.exit(0)
 
 
 if __name__ == "__main__":
